@@ -647,37 +647,6 @@ out:
 	return ret;
 }
 
-typedef struct {
-	GsApp *app;
-	GsAppState state;
-} AppStateData;
-
-static gboolean
-set_state_idle_cb (gpointer data)
-{
-	AppStateData *app_data = data;
-
-	gs_app_set_state (app_data->app, app_data->state);
-	g_object_unref (app_data->app);
-	g_free (app_data);
-
-	return G_SOURCE_REMOVE;
-}
-
-static void
-gs_app_set_state_in_idle (GsApp *app, GsAppState state)
-{
-	AppStateData *app_data;
-	guint id;
-
-	app_data = g_new (AppStateData, 1);
-	app_data->app = g_object_ref (app);
-	app_data->state = state;
-
-	id = g_idle_add (set_state_idle_cb, app_data);
-	g_source_set_name_by_id (id, "[gnome-software] set_state_idle_cb");
-}
-
 /******************************************************************************/
 
 /* async state */
@@ -2193,7 +2162,7 @@ gs_plugin_loader_app_action_thread_cb (GSimpleAsyncResult *res,
 						  state->cancellable,
 						  &error);
 	if (!state->ret) {
-		gs_app_set_state_in_idle (state->app, state->state_failure);
+		gs_app_set_state (state->app, state->state_failure);
 		gs_plugin_loader_app_action_state_finish (state, error);
 		g_error_free (error);
 		return;
@@ -2208,7 +2177,7 @@ gs_plugin_loader_app_action_thread_cb (GSimpleAsyncResult *res,
 
 	/* success */
 	if (state->state_success != GS_APP_STATE_UNKNOWN)
-		gs_app_set_state_in_idle (state->app, state->state_success);
+		gs_app_set_state (state->app, state->state_success);
 	gs_plugin_loader_app_action_state_finish (state, NULL);
 }
 
@@ -2242,13 +2211,18 @@ load_install_queue (GsPluginLoader *plugin_loader, GError **error)
 			continue;
 		app = gs_app_new (names[i]);
 		gs_app_set_state (app, GS_APP_STATE_QUEUED);
+
+		g_mutex_lock (&plugin_loader->priv->app_cache_mutex);
 		g_hash_table_insert (plugin_loader->priv->app_cache,
 				     g_strdup (gs_app_get_id (app)),
 				     g_object_ref (app));
+		g_mutex_unlock (&plugin_loader->priv->app_cache_mutex);
+
 		g_mutex_lock (&plugin_loader->priv->pending_apps_mutex);
 		g_ptr_array_add (plugin_loader->priv->pending_apps,
 				 g_object_ref (app));
 		g_mutex_unlock (&plugin_loader->priv->pending_apps_mutex);
+
 		g_debug ("adding pending app %s", gs_app_get_id (app));
 		gs_plugin_add_app (&list, app);
 		g_object_unref (app);
@@ -2478,6 +2452,7 @@ gs_plugin_loader_get_state_for_app (GsPluginLoader *plugin_loader, GsApp *app)
 	GsPluginLoaderPrivate *priv = plugin_loader->priv;
 	guint i;
 
+	g_mutex_lock (&plugin_loader->priv->pending_apps_mutex);
 	for (i = 0; i < priv->pending_apps->len; i++) {
 		tmp = g_ptr_array_index (priv->pending_apps, i);
 		if (g_strcmp0 (gs_app_get_id (tmp), gs_app_get_id (app)) == 0) {
@@ -2485,6 +2460,7 @@ gs_plugin_loader_get_state_for_app (GsPluginLoader *plugin_loader, GsApp *app)
 			break;
 		}
 	}
+	g_mutex_unlock (&plugin_loader->priv->pending_apps_mutex);
 	return state;
 }
 
