@@ -88,6 +88,22 @@ cancel_current_search (GsShellSearchProvider *self)
 	}
 }
 
+/**
+ * search_sort_by_kudo_cb:
+ **/
+static gint
+search_sort_by_kudo_cb (gconstpointer a, gconstpointer b)
+{
+	guint pa, pb;
+	pa = gs_app_get_kudos_percentage (GS_APP (a));
+	pb = gs_app_get_kudos_percentage (GS_APP (b));
+	if (pa < pb)
+		return 1;
+	else if (pa > pb)
+		return -1;
+	return 0;
+}
+
 static void
 search_done_cb (GObject *source,
 		GAsyncResult *res,
@@ -113,6 +129,9 @@ search_done_cb (GObject *source,
 		return;	
 	}
 
+	/* sort by kudos, as there is no ratings data by default */
+	list = g_list_sort (list, search_sort_by_kudo_cb);
+
 	g_variant_builder_init (&builder, G_VARIANT_TYPE ("as"));
 	for (l = list; l != NULL; l = l->next) {
 		GsApp *app = GS_APP (l->data);
@@ -225,7 +244,8 @@ handle_get_result_metas (GsShellSearchProvider2        *skeleton,
 		g_variant_builder_add (&meta, "{sv}", "id", g_variant_new_string (gs_app_get_id (app)));
 		g_variant_builder_add (&meta, "{sv}", "name", g_variant_new_string (gs_app_get_name (app)));
 		pixbuf = gs_app_get_pixbuf (app);
-		g_variant_builder_add (&meta, "{sv}", "icon", g_icon_serialize (G_ICON (pixbuf)));
+		if (pixbuf != NULL)
+			g_variant_builder_add (&meta, "{sv}", "icon", g_icon_serialize (G_ICON (pixbuf)));
 		g_variant_builder_add (&meta, "{sv}", "description", g_variant_new_string (gs_app_get_summary (app)));
 		meta_variant = g_variant_builder_end (&meta);
 		g_hash_table_insert (self->metas_cache, g_strdup (gs_app_get_id (app)), g_variant_ref_sink (meta_variant));
