@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2013 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2013-2014 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -60,7 +60,7 @@ const gchar	*appstream_app_get_summary		(AppstreamApp	*app);
 const gchar	*appstream_app_get_project_group	(AppstreamApp	*app);
 GHashTable	*appstream_app_get_urls			(AppstreamApp	*app);
 GPtrArray	*appstream_app_get_keywords		(AppstreamApp	*app);
-const gchar	*appstream_app_get_licence		(AppstreamApp	*app);
+const gchar	*appstream_app_get_project_license	(AppstreamApp	*app);
 const gchar	*appstream_app_get_description		(AppstreamApp	*app);
 const gchar	*appstream_app_get_icon			(AppstreamApp	*app);
 gboolean	 appstream_app_has_category		(AppstreamApp	*app,
@@ -90,8 +90,8 @@ void		 appstream_app_add_url			(AppstreamApp	*app,
 							 const gchar	*kind,
 							 const gchar	*summary,
 							 gsize		 length);
-void		 appstream_app_set_licence		(AppstreamApp	*app,
-							 const gchar	*licence,
+void		 appstream_app_set_project_license	(AppstreamApp	*app,
+							 const gchar	*project_license,
 							 gsize		 length);
 void		 appstream_app_set_project_group	(AppstreamApp	*app,
 							 const gchar	*project_group,
@@ -112,6 +112,18 @@ void		 appstream_app_add_keyword		(AppstreamApp	*app,
 void		 appstream_app_add_mimetype		(AppstreamApp	*app,
 							 const gchar	*mimetype,
 							 gsize		 length);
+void		 appstream_app_add_metadata		(AppstreamApp	*app,
+							 const gchar	*key,
+							 const gchar	*value,
+							 gsize		 length);
+const gchar	*appstream_app_get_metadata_item	(AppstreamApp	*app,
+							 const gchar	*key);
+void		 appstream_app_add_locale		(AppstreamApp	*app,
+							 const gchar	*locale,
+							 gsize		 length,
+							 guint		 percentage);
+guint		 appstream_app_has_locale		(AppstreamApp	*app,
+							 const gchar	*locale);
 void		 appstream_app_add_desktop_core		(AppstreamApp	*app,
 							 const gchar	*desktop,
 							 gsize		 length);
